@@ -517,7 +517,7 @@ class RedisRoot:
                 else:
                     field.value = None
                     cleaned_value = field.clean()
-                    allowed = self._filter_field_name(model, field_name, cleaned_value, filters)
+                    allowed = self._filter_field_name(field_name, cleaned_value, filters)
                     checked_instances[instance_id][field_name] = {
                         'value': cleaned_value,
                         'allowed': allowed
@@ -639,7 +639,7 @@ class RedisRoot:
         instances_with_allowed = {}
         for instance_id, instance_fields in instances.items():
             for field_name, field_value in instance_fields.items():
-                allowed = self._filter_field_name(model, field_name, field_value, filters)
+                allowed = self._filter_field_name(field_name, field_value, filters)
                 if instance_id not in instances_with_allowed.keys():
                     instances_with_allowed[instance_id] = {}
                 instances_with_allowed[instance_id][field_name] = {
